@@ -4,9 +4,7 @@ use Pcore qw[-class];
 
 use overload    #
   q[""] => sub {
-    my $self = shift;
-
-    return $self->old_umask;
+    return $_[0]->old_umask;
   },
   fallback => undef;
 
@@ -14,9 +12,7 @@ has old_umask => ( is => 'ro', isa => Int, required => 1 );
 
 no Pcore;
 
-sub DEMOLISH {
-    my $self = shift;
-
+sub DEMOLISH ( $self, $global ) {
     umask $self->old_umask;    ## no critic qw[InputOutput::RequireCheckedSyscalls]
 
     return;
