@@ -1,7 +1,7 @@
 package Pcore::Util::Text::Table;
 
 use Pcore qw[-class];
-use Text::ASCIITable qw[];    ## no critic qw(Modules::ProhibitEvilModules)
+use Text::ASCIITable qw[];    ## no critic qw[Modules::ProhibitEvilModules]
 
 has row_line => ( is => 'ro', isa => Bool, default => 1 );
 has _protect_spaces => ( is => 'rw', isa => Bool, default => 0, init_arg => undef );
@@ -60,9 +60,9 @@ sub render {
 
     my $res = $self->_obj->draw(
         [ q[┌], q[┐], q[─], q[┬] ],    # top line
-        [ q[│], q[│], q[│] ],            # header row
+        [ q[│], q[│], q[│] ],          # header row
         [ q[╞], q[╡], q[═], q[╪] ],    # header row separator
-        [ q[│], q[│], q[│] ],            # row repeated for each row
+        [ q[│], q[│], q[│] ],          # row repeated for each row
         [ q[└], q[┘], q[─], q[┴] ],    # bottom line
         [ q[├], q[┤], q[─], q[┼] ],    # only used if drawRowLine is enabled and to render addRowLine call
     );
